package be.iminds.ilabt.jfed.experiment.setup;

import org.jetbrains.annotations.Contract;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;

/**
 * This is more than just a logger: it handles fatal errors as well
 */
public interface ExperimentSetupLogger {
    @Contract("_ -> fail")
    default void fatal(@Nullable String val) {
        fatal(val, null);
    }

    @Contract("_,_ -> fail")
    void fatal(@Nullable String val, @Nullable Throwable t);



    void logExtraText(@Nonnull String name, @Nonnull Object value, boolean large);
    void logExtraXml(@Nonnull String name, @Nonnull Object value, boolean large);
    void logExtraHtml(@Nonnull String name, @Nonnull Object value, boolean large);
    void logExtraJson(@Nonnull String name, @Nonnull Object value, boolean large);


    void debug(@Nullable String val, @Nullable Throwable e, boolean formatAsCode);
    void info(@Nullable String val, @Nullable Throwable e, boolean formatAsCode);
    void warn(@Nullable String val, @Nullable Throwable e, boolean formatAsCode);
    void error(@Nullable String val, @Nullable Throwable e, boolean formatAsCode);

    default void debug(@Nullable String val, boolean formatAsCode) { debug(val, null, formatAsCode); }
    default void info(@Nullable String val, boolean formatAsCode) { info(val, null, formatAsCode); }
    default void warn(@Nullable String val, boolean formatAsCode) { warn(val, null, formatAsCode); }
    default void error(@Nullable String val, boolean formatAsCode) { error(val, null, formatAsCode); }

    default void debug(@Nullable String val, @Nullable Throwable e) { debug(val, e, false); }
    default void info(@Nullable String val, @Nullable Throwable e) { info(val, e, false); }
    default void warn(@Nullable String val,  @Nullable Throwable e) { warn(val, e, false); }
    default void error(@Nullable String val, @Nullable Throwable e) { error(val, e, false); }

    default void debug(@Nullable String val) { debug(val, null, false); }
    default void info(@Nullable String val) { info(val, null, false); }
    default void warn(@Nullable String val) { warn(val, null, false); }
    default void error(@Nullable String val) { error(val, null, false); }
}
